# nleis.py

`nleis.py` is designed as a toolbox that enables nonlinear impedance analysis for impedance.py. Key features include nonlinear ECMs and simultaneous analysis of EIS and 2nd-NLEIS. It will soon be integrated into `impedance.py`. This repo will contains most recent developer version of `nleis.py`. As of today `nleis.py` supports the latest version of `impedance.py 1.7.1`

### Installation

The `nleis.py` is avaliable in a standalone version now. You can install it directly with pip.

```bash
pip install nleis
```

See [Getting started with nleis.py](https://nleispy.readthedocs.io/en/latest/getting-started.html) for instructions on how to get most of this toolbox.

In the near future, you can directly install `impedance.py` using pip and you will be able to access all the funcationality for `nleis.py`.

```bash
pip install impedance
```

#### Dependencies

`nleis.py` requires the same dependencies as `impedance.py` puls the latest version of `impedance.py`:

-   Python (>=3.7)
-   SciPy (>=1.0)
-   NumPy (>=1.14)
-   Matplotlib (>=3.0)
-   Altair (>=3.0)
-   impedance(>=1.7.1)


#### Examples and Documentation

The detailed documentation can be found at [nleispy.readthedocs.io](https://nleispy.readthedocs.io/en/latest).


### Credits
----------------------------------------------------------------

This work adopted and built the `nleis.py` based on [impedance.py](https://github.com/ECSHackWeek/impedance.py) (Murbach, M., Gerwe, B., Dawson-Elli, N., & Tsui, L. (2020). impedance.py: A Python package for electrochemical impedance analysis. Journal of Open Source Software, 5. https://doi.org/10.21105/joss.02349)


----------------------------------------------------------------
